@@ -59,11 +59,15 @@ class MasterSignals:
         connection = transaction.get_connection(using)
         if not connection.in_atomic_block:
             instance.reset_cqrs_saves_count()
-            instance_data = instance.to_cqrs_dict(using)
+            instance_data = instance.to_cqrs_dict(using, sync=sync)
             previous_data = instance.get_tracked_fields_data()
             signal_type = SignalType.SYNC if sync else SignalType.SAVE
             payload = TransportPayload(
-                signal_type, sender.CQRS_ID, instance_data, instance.pk, queue,
+                signal_type,
+                sender.CQRS_ID,
+                instance_data,
+                instance.pk,
+                queue,
                 previous_data,
             )
             producer.produce(payload)
@@ -92,6 +96,11 @@ class MasterSignals:
             'cqrs_revision': instance.cqrs_revision + 1,
             'cqrs_updated': str(now()),
         }
+
+        data = instance.get_custom_cqrs_delete_data()
+        if data:
+            instance_data['custom'] = data
+
         signal_type = SignalType.DELETE
 
         payload = TransportPayload(signal_type, sender.CQRS_ID, instance_data, instance.pk)
