@@ -4,6 +4,7 @@ from django.conf import settings
 from django.utils.module_loading import import_string
 
 from dj_cqrs.transport.base import BaseTransport
+from dj_cqrs.transport.kombu import KombuTransport
 from dj_cqrs.transport.rabbit_mq import RabbitMQTransport
 
 
@@ -22,4 +23,4 @@ except (ImportError, ValueError):
     raise ImportError('Bad CQRS transport class.')
 
 
-__all__ = [BaseTransport, RabbitMQTransport, current_transport]
+__all__ = [BaseTransport, KombuTransport, RabbitMQTransport, current_transport]
